import sqlite3


class InfoManager:
    def __init__(self, db_path):
        self.db_path = db_path
        self.conn = sqlite3.connect(self.db_path)
        self._create_table()

    def _create_table(self):
        """在数据库中创建一个表，如果它还不存在的话"""
        try:
            c = self.conn.cursor()
            c.execute('''CREATE TABLE IF NOT EXISTS information (id INTEGER PRIMARY KEY, name TEXT UNIQUE NOT NULL)''')
            self.conn.commit()
        except sqlite3.Error as e:
            print(f"数据库错误: {e}")
        finally:
            self.conn.close()

    def add_info(self, name):
        """向数据库中添加一个新的信息名"""
        try:
            c = self.conn.cursor()
            c.execute("INSERT INTO information (name) VALUES (?)", (name,))
            self.conn.commit()
            print("信息名成功添加")
        except sqlite3.IntegrityError:
            print("信息名已存在")
        except sqlite3.Error as e:
            print(f"数据库错误: {e}")

    def info_exists(self, name):
        """检查特定的信息名是否已存在于数据库中"""
        try:
            c = self.conn.cursor()
            c.execute("SELECT * FROM information WHERE name=?", (name,))
            return c.fetchone() is not None
        except sqlite3.IntegrityError:
            return None
        except sqlite3.Error as e:
            print(e)
            return None

    def list_info(self):
        """列出数据库中所有的信息名"""
        try:
            c = self.conn.cursor()
            c.execute("SELECT name FROM information")
            names = [row[0] for row in c.fetchall()]
            return names
        except sqlite3.IntegrityError:
            return None
        except sqlite3.Error as e:
            print(e)
            return None

    def __del__(self):
        """确保关闭数据库连接"""
        self.conn.close()

# 使用示例
# if __name__ == "__main__":
#     db_path = "example.db"
#     manager = InfoManager(db_path)
#
#     # 添加信息名
#     manager.add_info("ExampleName1")
#     manager.add_info("ExampleName2")
#
#     # 检查信息名是否存在
#     name_to_check = "ExampleName1"
#     if manager.info_exists(name_to_check):
#         print(f"信息名 {name_to_check} 存在")
#     else:
#         print(f"信息名 {name_to_check} 不存在")
#
#     # 列出所有信息名
#     print("所有存储的信息名:")
#     for name in manager.list_info():
#         print(name)
