import logging

from qbittorrent import Client


class QBittorrentManager:
    def __init__(self, url, username, password):
        self.username = username
        self.password = password
        self.client = Client(url)

    def login(self):
        return self.client.login(self.username, self.password)

    def add_torrent(self, torrent):
        """添加torrent，可以是文件路径或磁力链接"""
        if torrent.startswith('magnet:'):
            self.client.download_from_link(torrent)
        else:
            self.client.download_from_file(open(torrent, 'rb'))

    def get_torrent_filters(self, **filters):
        """获取当前所有torrents的列表"""
        return self.client.torrents(**filters)

    def get_torrents(self):
        """获取当前所有torrents的列表"""
        return self.client.torrents()

    def get_torrents_hash(self, torrent_hash):
        """获取当前所有torrents的列表"""
        return self.client.get_torrent(torrent_hash)

    def get_torrents_hash_file(self, torrent_hash):
        """获取当前所有torrents的列表"""
        return self.client.get_torrent_files(torrent_hash)

    def pause(self, torrent_hash):
        """暂停指定的torrent"""
        self.client.pause(torrent_hash)

    def resume(self, torrent_hash):
        """恢复指定的torrent"""
        self.client.resume(torrent_hash)

    def delete_torrent(self, torrent_hash):
        """
        删除指定的torrent。如果delete_files为True，则同时删除文件。

        :param torrent_hash: 要删除的torrent的哈希值
        """
        self.client.delete_permanently(torrent_hash)
        logging.info(f"Torrent {torrent_hash} 删除成功，同时删除文件")
