import time

from pyarr import RadarrAPI
import json


class RadarClient:
    def __init__(self, url, key):
        self.url = url
        self.api_key = key
        self.client = RadarrAPI(self.url, self.api_key)

    def get_all_movies(self):
        return self.client.get_movie()

    def delete_movie(self, movie_id):
        return self.client.del_movie(movie_id, delete_files=True)

    def save_movies_to_json(self, file_name='data/movies.json'):
        movies = self.get_all_movies()
        with open(file_name, 'w') as f:
            json.dump(movies, f, indent=4)
        print(f"Movies saved to {file_name}")

    def get_already_movies(self):
        """获取全部已经跟踪已经处理完成的电影"""
        already_processed = set()  # 用于跟踪已处理的电影
        movies = self.get_all_movies()
        for movie in movies:
            if 'movieFile' in movie and movie['movieFile'] and movie['id'] not in already_processed:
                already_processed.add(movie['id'])
        return already_processed

    def continuous_monitoring(self, check_interval=60, custom_action=None):
        """
        Continuously monitor movies and perform a custom action if movieFile exists.
        check_interval: Time in seconds between checks
        custom_action: Function to be called for each downloaded movie
        """
        already_processed = set()  # 用于跟踪已处理的电影
        while True:
            movies = self.get_all_movies()
            for movie in movies:
                if 'movieFile' in movie and movie['movieFile'] and movie['id'] not in already_processed:
                    custom_action(movie)
                    already_processed.add(movie['id'])
            time.sleep(check_interval)

    def find_movie_id_by_filename(self, filename):
        """根据文件名搜索并返回已完成下载的电影的 ID"""
        try:

            movies = self.get_all_movies()
            for movie in movies:
                # 检查电影是否已下载
                if 'movieFile' in movie and movie['movieFile']:
                    movie_file_name = movie['movieFile']['relativePath']
                    # 检查文件名是否匹配
                    if filename in movie_file_name:
                        return movie['id']
            return None
        except Exception as e:
            return None

    def get_all_movie_names(self):
        """获取所有电影名称的集合"""
        movie_names = set()
        movies = self.get_all_movies()
        for movie in movies:
            if 'movieFile' in movie and movie['movieFile']:
                movie_file_name = movie['movieFile']['relativePath']
                movie_names.add(movie_file_name)
        return movie_names

