import signal
import time

from src.services.QbService import QbService


class QbApp:
    def __init__(self, config, parent_directory, socketio):
        self.is_running = True

        self.qb_service = QbService(config, parent_directory, socketio)

        # 注册信号处理函数
        signal.signal(signal.SIGINT, self.handle_signal)

    def handle_signal(self, signum, frame):
        """处理中断信号，优雅地退出循环"""
        self.is_running = False
        print("Exiting...")

    def main_loop(self):

        """执行主循环，处理用户输入"""
        while True:
            # 显示可用命令
            print("\n可用命令: add <磁力链接>, quit")
            cmd = input("请输入命令: ").strip().lower()
            if cmd == 'quit':
                print("正在退出程序...")
                self.qb_service.stop_monitoring()
                break  # 退出循环，结束程序
            elif cmd.startswith('add '):
                magnet_link = cmd[4:]  # 获取磁力链接
                if magnet_link:
                    self.add(magnet_link)  # 调用添加磁力链接的方法
                    print(f"添加了磁力链接: {magnet_link}")
                else:
                    print("磁力链接无效，请重新输入。")
            else:
                print("未知命令，请重新输入。")

    def init(self):
        self.qb_service.init()

    def start(self):
        self.qb_service.start_monitoring()

    def stop(self):
        self.qb_service.stop_monitoring()

    def add(self, torrent):
        new_torrent_hash = self.qb_service.send_to_qb(torrent)
        print(f"新添加的torrent哈希值: {new_torrent_hash}")
