import json
import logging
import os
import signal
import threading
import time

from src.api.NasToolsClient import NasToolsClient
from src.services.Aria2Service import Aria2Service
from src.services.RemoteDownloadSerivce import RemoteDownloadService


def save_directory_contents_to_json(directory_contents,
                                    json_file_path=''):
    with open(json_file_path, 'w', encoding='utf-8') as f:
        json.dump(directory_contents, f, indent=4, ensure_ascii=False)


class Application:
    def __init__(self, config, parent_directory, remote_download_service=True):
        self.config = config
        self.parent_dir = parent_directory
        # base_url = config['NSTOOLS']['URL']
        # api_key = config['NSTOOLS']['API_KEY']
        #
        # self.nas_tools_api = NasToolsClient(base_url, api_key)

        self.aria2_service = Aria2Service(config)

        if remote_download_service:
            self.remote_download_service = RemoteDownloadService(config, parent_directory)

        self.is_running = True

        # 注册信号处理函数
        signal.signal(signal.SIGINT, self.handle_signal)

    def test_nas_tools_service(self):
        pass

    def handle_signal(self, signum, frame):
        """处理中断信号，优雅地退出循环"""
        self.is_running = False
        print("Exiting...")

    def start_remote_download(self):
        self.remote_download_service.start_monitoring()

    def stop_remote_download(self):
        self.remote_download_service.stop_monitoring()

    def start_aria2_monitoring(self):
        self.aria2_service.start_monitoring()

    def stop_aria2_monitoring(self):
        self.aria2_service.stop_monitoring()

    def run(self):
        self.start_remote_download()
        self.start_aria2_monitoring()

    def main_loop(self):
        # 主循环
        while self.is_running:
            # print("Running...")
            time.sleep(1)  # 模拟任务执行
        print("Stopped.")
        self.stop_remote_download()
        self.stop_aria2_monitoring()
