import threading
import logging
import os
import shutil
import time


class Aria2FileCopyTask:
    def __init__(self, aria2_api, nas_tools_api, download_path, destination_path, check_interval):
        self.nas_tools_api = nas_tools_api
        self.aria2_api = aria2_api
        self.download_path = download_path
        self.destination_path = destination_path
        self.is_running = False
        self.thread = None
        self.check_interval = check_interval

    def start_monitoring(self):
        if not self.is_running:
            self.is_running = True
            self.thread = threading.Thread(target=self.monitor_aria2_and_move)
            self.thread.start()

    def stop_monitoring(self):
        self.is_running = False
        if self.thread:
            self.thread.join()

    def copy_new_files(self, src_dir, dest_dir):
        """复制新文件和目录，如果它们在目标目录中不存在"""
        if not os.path.exists(dest_dir):
            os.makedirs(dest_dir)
        for item in os.listdir(src_dir):
            src_item = os.path.join(src_dir, item)
            dest_item = os.path.join(dest_dir, item)

            # 如果是目录
            if os.path.isdir(src_item):
                # 检查目标目录是否存在
                if not os.path.exists(dest_item):
                    # 直接复制整个目录
                    shutil.copytree(src_item, dest_item)
                    logging.info(f"Copied directory from {src_item} to {dest_item}")
                else:
                    # 如果目标目录已存在，递归处理子目录内容
                    self.copy_new_files(src_item, dest_item)
            elif not item.endswith('.aria2'):  # 检查是否为 .aria2 文件
                # 如果是文件，且不是 .aria2 文件，则进行复制
                if not os.path.exists(dest_item):
                    shutil.copy(src_item, dest_item)
                    logging.info(f"Copied file from {src_item} to {dest_item}")
                    # 添加复制完成的提示
                    logging.info(f"Copy complete {dest_item} ")
                    self.nas_sync()
                    logging.info("Completed checking for new files to copy.")
                else:
                    logging.info(f"File already exists, skipping: {dest_item}")

    def monitor_aria2_and_move(self):
        logging.info("Starting monitoring aria2 is complete and move to " + self.destination_path)
        while self.is_running:
            # 获取 Aria2 当前的下载列表
            downloads = self.aria2_api.get_downloads()
            for download in downloads:
                if download.is_complete:
                    # 检查下载的每个文件
                    for file in download.files:
                        if file.selected:
                            filename = os.path.basename(file.path)
                            file_path = os.path.join(self.download_path + '/movie', filename)
                            temp_file = file_path + '.aria2'
                            print(f'temp_file: {temp_file}')
                            if os.path.exists(file_path) and not os.path.exists(temp_file):
                                self.move_new_files(self.download_path, self.destination_path)

            time.sleep(10)

    def nas_sync(self):
        logging.info("Notify nas tools synchronization")
        self.nas_tools_api.login('admin', 'password')
        # self.nas_tools_api.run_service('sync')

        directory_ids = [29, 30]

        # for directory_id in sync_directories:
        #     directory_info = sync_directories[directory_id]
        #     directory_ids.append(directory_info["id"])

        for directory_id in directory_ids:
            self.nas_tools_api.sync(directory_id)

    def move_new_files(self, src_dir, dest_dir):
        """移动新文件和目录，如果它们在目标目录中不存在"""
        if not os.path.exists(dest_dir):
            os.makedirs(dest_dir)
        for item in os.listdir(src_dir):
            src_item = os.path.join(src_dir, item)
            dest_item = os.path.join(dest_dir, item)

            # 如果是目录
            if os.path.isdir(src_item):
                # 检查目标目录是否存在
                if not os.path.exists(dest_item):
                    # 直接移动整个目录
                    shutil.move(src_item, dest_item)
                    logging.info(f"Moved directory from {src_item} to {dest_item}")
                else:
                    # 如果目标目录已存在，递归处理子目录内容
                    self.move_new_files(src_item, dest_item)
            elif not item.endswith('.aria2'):  # 检查是否为 .aria2 文件
                # 如果是文件，且不是 .aria2 文件，则进行移动
                if not os.path.exists(dest_item):
                    shutil.move(src_item, dest_item)
                    logging.info(f"Moved file from {src_item} to {dest_item}")
                    # 添加移动完成的提示
                    logging.info(f"move complete {dest_item} ")
                    self.nas_sync()
                    logging.info("Completed checking for new files to move.")
                else:
                    logging.info(f"File already exists, skipping: {dest_item}")
